# AdviseInput

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**application_stack** | [**PythonStack**](PythonStack.md) |  |
**runtime_environment** | [**RuntimeEnvironment**](RuntimeEnvironment.md) |  | [optional]
**library_usage** | [**AdviseInputLibraryUsage**](AdviseInputLibraryUsage.md) |  | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
